@@ -9,24 +9,37 @@ var defaultConfig = {
 var DEBUG = false
 
 function ON_DEATH (callback) {
+  var handlers = [];
   Object.keys(defaultConfig).forEach(function(key) {
     var val = defaultConfig[key]
+    var handler = null;
     if (val) {
-      if (DEBUG)
-        process.on(key, function() {
+      if (DEBUG) {
+        handler = function() {
           var args = Array.prototype.slice.call(arguments, 0)
           args.unshift(key)
           console.log('Trapped ' + key)
           callback.apply(null, args)
-        })
-      else
-        process.on(key, function() {
+        };
+        process.on(key, handler)
+      } else {
+        handler = function() {
           var args = Array.prototype.slice.call(arguments, 0)
           args.unshift(key)
           callback.apply(null, args)
-        })
+        }
+        process.on(key, handler)
+      }
+      handlers.push([key, handler])
     }
   })
+  return function OFF_DEATH() {
+    handlers.forEach(function (args) {
+      var key = args[0];
+      var handler = args[1];
+      process.removeListener(key, handler);
+    })
+  }
 }
 
 module.exports = function (arg) {
@@ -46,7 +59,7 @@ module.exports = function (arg) {
 
     return ON_DEATH
    } else if (typeof arg === 'function') {
-    ON_DEATH(arg)
+    return ON_DEATH(arg)
   }
 }
 
